@@ -112,7 +112,7 @@ class Injector:
         duration = time() - time_start
         log.debug("%s (%d)", response.status_code, duration)
         if response.status_code != 200:
-            raise EegoBadResponseError
+            raise EegoBadResponseError(f"API return status code {response.status_code}")
 
     def commit(self) -> None:
         requests.patch(
@@ -379,18 +379,23 @@ class RtInjector(Injector):
                             message["ContentType"],
                         )
                         continue
-                    doc = self.message_reader(message, ticket_modtime)
+                    doc = self.build_payload(ticket["id"], message, ticket_modtime)
                     if doc is None:
                         continue
                     if doc.title:
                         log.debug('Sending doc with title "%s"', doc.title)
                     else:
                         log.debug("Sending doc with type '%s'", event["Type"])
-                    self.send_to_api(doc)
+                    try:
+                        self.send_to_api(doc)
+                    except Exception as e:
+                        log.error(
+                            f"Failed to index transaction {event_link['id']} from ticket {ticket['id']}. Reason: {e}"
+                        )
         log.info(f"Finished indexing ticket {ticket['id']}")
 
-    def message_reader(
-        self, message: dict[str, Any], ticket_modtime: float
+    def build_payload(
+        self, ticket_id: int, message: dict[str, Any], ticket_modtime: float
     ) -> Document | None:
         raw_content = b64decode(message["Content"])
         if message["ContentType"] == "application/pdf":
@@ -414,7 +419,7 @@ class RtInjector(Injector):
             content = raw_content.decode("utf-8")
             url = (
                 self.base_uri
-                + "Transaction/Display.html?id="
+                + f"Ticket/Display.html?id={ticket_id}#txn-"
                 + str(message["TransactionId"]["id"])
             )
             title, _ = decode_header(message["Subject"])[0]
